from setuptools import setup, find_packages

setup(name='ixi_algs',
      version='0.5',
      description='ixi_algs',
      package_dir={'': 'src'},
      packages=find_packages(where='src'),
      author_email='zxcbbtihs37docxh@yandex.ru',
      zip_safe=False)